#
#-------------------------------------------------------------------------------
#  @(#) xml-3gpp/tech_pack_support/Ericsson_SGSN/v7.0/UserConfig.pm xml-3gpp_d3.2.2.5:aset.002096:1:1@(#)
#-------------------------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Ericsson SGSN R7
#
#Copyright (c) Vallent Software Systems UK 2007. All rights reserved.
#
package UserConfig;


@ISA = qw(Exporter);
@EXPORT = qw(postparser_config);

use strict;
use AudLog; 
use Exporter ();

my @rules = (

###-------------Rules for BSBGP SGSN---------------
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join BSBGP files ',
        INPUT_FILE_DESCRIPTION => ['^bss-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'bss',
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'BSS-SGSN',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
         RULE_TYPE                    => 'DATALINE_WHERE',
         RULE_DESC                    => 'DATALINE_WHERE to split for BSBGP_SGSN ',
         INPUT_FILE_DESCRIPTION       => ['^(BSS-SGSN-#-.*-#-)\d{2}\w{3}\d{4}-#-\d{2}:\d{2}:\d{2}-#-\d+-#-J.pif'],
         PRODUCE_PIF => 'True',
         OUTPUT_FORMAT => 0,
         COUNTER_NAMES  =>
             [
              {
                  COUNTER_NAME  => 'bssgpAttResumeProc',
                  KEEP_WHERE    => [ '\d+' ],
                  REMOVE_WHERE  => [ '^$' ],
              },
              {
                  COUNTER_NAME  => 'bssgpAttSuspendProc',
                  KEEP_WHERE  => [ '\d+' ],
                  REMOVE_WHERE  => [ '^$' ],
              },
             ],
         REDUNDANT_DATA_COUNTERS => [ 
	 			     'bssgpDownlinkPacketsSignalling', 'bssgpUplinkPackets', 'bssgpUplinkOctets',
	 			     'bssgpUplinkPacketsSignalling', 'bssgpDownlinkOctets', 'bssgpDownlinkPackets'
		         ],
         OUTPUT_BLOCK_NAME => 'BSBGP_SGSN',
         FILENAME_ADDITION => 'BSBGP_SGSN',
},

{
        RULE_TYPE                 => 'UNPEGGER',
        RULE_DESC                 => 'Unpeg BSBGP_SGSN data',
        INPUT_FILE_DESCRIPTION    => ['^(BSS-SGSN-#-.*-#-).*-#-\d{2}:\d{2}:\d{2}-#-\d+-#-J-#-BSBGP_SGSN-#-DW.pif'],
        INPUT_FILE_DATETIME_KEY   => '^BSS-SGSN-#-.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-\d+-#-J-#-BSBGP_SGSN-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id)],
        PEG_COUNTERS              => {'bssgp\w+' => '4294967295',},
},

###------Rules for block BSBGP NSVC------------------------------------------------------------
 
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join BSBGP files ',
        INPUT_FILE_DESCRIPTION => ['^bss-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'bss',
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'BSS-NSVC',
        REDUNDANT_HEADER_COUNTERS => [],
}, 

{
        RULE_TYPE                    => 'DATALINE_WHERE',
        RULE_DESC                    => 'DATALINE_WHERE to split joined bsbgp for BSBGP_NSVC ',
        INPUT_FILE_DESCRIPTION       => ['^(BSS-NSVC-#-.*-#-)\d{2}\w{3}\d{4}-#-\d{2}:\d{2}:\d{2}-#-\d+-#-J.pif'],
        PRODUCE_PIF => 'True',
        OUTPUT_FORMAT => 0,
        COUNTER_NAMES  =>
             [
              {
                  COUNTER_NAME  => 'bssgpUplinkPacketsSignalling',
                  KEEP_WHERE  => [ '\d+' ],
                  REMOVE_WHERE  => [ '^$' ],
              },
              {
                  COUNTER_NAME  => 'bssgpDownlinkPacketsSignalling',
                  KEEP_WHERE    => [ '\d+' ],
                  REMOVE_WHERE  => [ '^$' ],
              },
             ],
        REDUNDANT_DATA_COUNTERS => [ 'bssgpAttSuspendProc', 'bssgpAttResumeProc', 'Record_measurement_count', 'moid' ],
        REDUNDANT_DATA_COUNTERS => [ 'bssgpAttSuspendProc', 'bssgpAttResumeProc', 'Record_measurement_count', ],
        OUTPUT_BLOCK_NAME => 'BSBGP_NSVC',
        FILENAME_ADDITION => 'BSBGP_NSVC',
},
 
{
        RULE_TYPE                 => 'UNPEGGER',
        RULE_DESC                 => 'Unpeg BSBGP_NSVC data',
        INPUT_FILE_DESCRIPTION    => ['^(BSS-NSVC-#-.*-#-).*-#-\d{2}:\d{2}:\d{2}-#-\d+-#-J-#-BSBGP_NSVC-#-DW.pif'],
        INPUT_FILE_DATETIME_KEY   => '^BSS-NSVC-#-.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-\d+-#-J-#-BSBGP_NSVC-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
                                        STARTDATE => 'mts_Date',
                                        STARTTIME => 'mts_Time',
                                        DURATION  => 'gp',
                                        FORMAT    => 'seconds',
                                     },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS              => { 'bssgp\w+' => '4294967295', },
},


### -------------------------Block ISYSC -----------------------------------##
{
        RULE_TYPE                 => 'UNPEGGER',
        RULE_DESC                 => 'Unpeg ISYSC data',
        INPUT_FILE_DESCRIPTION    => '^(ISYSC-#-)\d{2}\w{3}\d{4}-#-\d{2}:\d{2}:\d{2}-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^ISYSC-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        OUTPUT_BLOCK_NAME         => 'ISYSC',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
                                         STARTDATE => 'mts_Date',
                                         STARTTIME => 'mts_Time',
                                         DURATION  => 'gp',
                                         FORMAT    => 'seconds',
                                     },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS              => {
                                         'ISYSC\w+' => '4294967295',
                                     },
},


## -------------------------Block IPSEC -----------------------------------##
{
        RULE_TYPE                 => 'UNPEGGER',
        RULE_DESC                 => 'Unpeg IPSEC data',
        INPUT_FILE_DESCRIPTION    => '^(ips-#-)\d{2}\w{3}\d{4}-#-\d{2}:\d{2}:\d{2}-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^ips-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        OUTPUT_BLOCK_NAME         => 'Ipsec',
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS              => {
                                       'ipsec\w+' => '4294967295',
                                     },
 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id for Ipsec',
        INPUT_FILE_DESCRIPTION    => 'UNPEG-#-ips-#-\d{2}\w{3}\d{4}-#-\d{2}:\d{2}:\d{2}-#-(.*)-#-.*-#-I.pif',
        DATA_COUNTERS_OP => sub {
                                my $d_ref = shift;
                                my @data = split('\.',$d_ref->{moid});
                                $d_ref->{"Mag_Id"}  = $data[0];
                                my $slot_id1 	= $data[1];
                                my $slot_id2	= $data[2];
                                
                                if ($slot_id2 =~ /^$/){
                                    $d_ref->{"Slot_Id"} = $slot_id1;
                                } else {
                                    $d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
                                }
                                
                                for my $d_key (keys %$d_ref) {
                                    my $name = $d_key;
                                    if ($d_ref->{$name} =~ /NULL/) {
                                        delete $d_ref->{$name};
                                    }
                                }
                                return 0;
                            },
        FILENAME_SUFFIX         => 'Ipsec',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        OUTPUT_BLOCK_NAME      => 'Ipsec',
},

 
### * * * MM_SM_SEC_GTP_SMS * * * * ####
## -------------------------Block GTP -----------------------------------##
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg GTP data',
        INPUT_FILE_DESCRIPTION    => '^(GTP-#-)\d{2}\w{3}\d{4}-#-\d{2}:\d{2}:\d{2}-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^GTP-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'GTP_\w+' => '4294967295',
        },
 },

####---------------------------Block MM_IndexG -----------------------------------------###
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join MM_Index files ',
        INPUT_FILE_DESCRIPTION => ['^MM-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'MM_IndexG',
        REDUNDANT_DATA_COUNTERS => ['Record_measurement_count', 'MM_NbrActAttachedSub_G', 'MM_NbrHomeSub_G', 'MM_NbrVisitingForeign_G', 'MM_NbrVisitingNatSub_G', 'MM_UnsuccAttachCC13_G', 'MM_UnsuccAttachCC14_G', 'MM_UnsuccAttachCC15_G', 'MM_UnsuccAttachCC22_G', 'MM_UnsuccAttachCC7_G', 'MM_UnsuccAttachCC8_G', 'MM_UnsuccInterSgsnRauCC14_U', 'MM_UnsuccAttachCC15_U', 'MM_UnsuccIntraSgsnRauCC14_G', 'MM_nbrDetachedInactiveSub_G', 'MM_UnsuccServiceReq_U', 'MM_UnsuccIntraSgsnRauCC14_U', 'MM_AttDetachInactiveSub_G', 'MM_UnsuccInterSgsnRauCC17_G', 'MM_UnsuccAttachCC22_U', 'MM_UnsuccAttachCC7_U', 'MM_UnsuccAttachCC14_U', 'MM_NbrVisitingNatSub_U', 'MM_NbrCamelSub_G', 'MM_AttServiceReqData_U', 'MM_UnsuccInterSgsnRauCC17_U', 'MM_NbrCamelSub_U', 'MM_UnsuccIntraSgsnRauCC17_G', 'MM_UnsuccAttachCC17_G', 'MM_UnsuccAttachCC13_U', 'MM_UnsuccIntraSgsnRauCC17_U', 'MM_UnsuccAttachCC17_U', 'MM_AttServiceRequest_U', 'MM_NbrVisitingForeign_U', 'MM_NbrSubPmmConnected', 'MM_UnsuccInterSgsnRauCC9_G', 'MM_NbrHomeSub_U', 'MM_UnsuccInterSgsnRauCC14_G', 'MM_UnsuccInterSgsnRauCC9_U', 'MM_NbrActAttachedSub_U', 'MM_UnsuccAttachCC8_U'],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'MM_IndexG',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE           => 'DATALINE_WHERE',
        RULE_DESC           => 'DATALINE_WHERE to split joined MM_Index ',
        INPUT_FILE_DESCRIPTION       => ['^MM_IndexG-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
        PRODUCE_PIF => "True",
        OUTPUT_FORMAT => 0,
        COUNTER_NAMES  =>
                 [
                     {
                'COUNTER_NAME'  => 'moid',
                'KEEP_WHERE'    => [ '\w+' ],
                'REMOVE_WHERE'  => [ '^$' ],
                     },
                 ],
},

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg MM data',
        INPUT_FILE_DESCRIPTION    => '^(MM_IndexG-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'MM_Att\w+' => '4294967295',
            'MM_Succ\w+' => '4294967295',
        },

 },

#######Start-----------------------Block MM_indexU-------------------------------------------### 

{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join MM_Index files ',
        INPUT_FILE_DESCRIPTION => ['^MM-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'MM_IndexU',
        REDUNDANT_DATA_COUNTERS => ['MM_SuccFirstPsPagingIu', 'MM_AttDetachInactiveSub_G', 'MM_AttachedLost_G', 'MM_NbrActAttachedSub_G', 'MM_NbrCamelSub_G', 'MM_NbrHomeSub_G', 'MM_NbrSubPmmConnected', 'MM_NbrVisitingForeign_G', 'MM_NbrVisitingNatSub_G', 'MM_nbrDetachedInactiveSub_G', 'MM_AttCombiInterSgsnRaUpdate_G', 'MM_AttCombiIntraSgsnRaUpdate_G', 'MM_AttGprsAttach_G', 'MM_AttGprsDetachMs_G', 'MM_AttGprsDetachSgsn_G', 'MM_AttImsiCombiInterSgsnRaUpdate_G', 'MM_AttImsiCombiIntraSgsnRaUpdate_G', 'MM_AttInterSgsnRaUpdate_G', 'MM_AttIntraSgsnRaUpdate_G', 'MM_AttNormalIntraSgsnRaUpdate_G', 'MM_AttPsPagingProcGb', 'MM_NbrActAttachedSubRA_G', 'MM_SuccCombiInterSgsnRaUpdate_G', 'MM_SuccCombiIntraSgsnRaUpdate_G', 'MM_SuccFirstPsPagingGb', 'MM_SuccGprsAttach_G', 'MM_SuccGprsDetachSgsn_G', 'MM_SuccInterSgsnRaUpdate_G', 'MM_SuccIntraSgsnRaUpdate_G', 'MM_SuccNormalIntraSgsnRaUpdate_G', 'MM_SuccPsPagingProcGb'],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'MM_IndexU',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE           => 'DATALINE_WHERE',
        RULE_DESC           => 'DATALINE_WHERE to split joined MM_Index ',
        INPUT_FILE_DESCRIPTION       => ['^MM_IndexU-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
        PRODUCE_PIF => "True",
        OUTPUT_FORMAT => 0,
        COUNTER_NAMES  =>
                 [
                     {
                'COUNTER_NAME'  => 'moid',
                'KEEP_WHERE'    => [ '\w+' ],
                'REMOVE_WHERE'  => [ '^$' ],
                     },
                 ],
},

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg MM data',
        INPUT_FILE_DESCRIPTION    => '^(MM_IndexU-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'MM_Att\w+' => '4294967295',
            'MM_Succ\w+' => '4294967295',
        },

 },

#######End-----------------------Block MM_indexU-------------------------------------------### 

######## -------------------Block MM_nonindexed ----------------------------------#####
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for MM_nonindexed Block',
        INPUT_FILE_DESCRIPTION => ['^MM-#-(.*-#-.*-#-.*)-#-.*-#-I.pif', '^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif', 'REL-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],        OUTPUT_BLOCK_NAME => 'MM_nonindexed',
        REDUNDANT_DATA_COUNTERS => [ 'MM_AttCombiInterSgsnRaUpdate_G', 'MM_AttCombiIntraSgsnRaUpdate_G', 'MM_AttImsiCombiInterSgsnRaUpdate_G', 'MM_AttImsiCombiIntraSgsnRaUpdate_G', 'MM_AttNormalIntraSgsnRaUpdate_G', 'MM_AttNormalIntraSgsnRaUpdate_U', 'MM_AttPsPagingProcIu', 'MM_AttachedLost_G', 'MM_AttachedLost_U', 'MM_NbrActAttachedSubRA_G', 'MM_NbrActAttachedSubRA_U', 'MM_SuccCombiInterSgsnRaUpdate_G', 'MM_SuccCombiIntraSgsnRaUpdate_G', 'MM_SuccGprsDetachSgsn_G', 'MM_SuccGprsDetachSgsn_U', 'MM_SuccNormalIntraSgsnRaUpdate_G', 'MM_SuccNormalIntraSgsnRaUpdate_U', 'MM_SuccPsPagingProcIu', 'Record_measurement_count', 'discardedPayloadPacket', 'discardedSessionMgmnt', 'moid', 'SM_SuccActPdpContextRa_U', 'SM_SuccActPdpContextRa_G', 'SM_AttActPdpContextRa_U', 'SM_AttActPdpContextRa_G', 'MM_SuccFirstPsPagingGb', 'MM_SuccFirstPsPagingIu', 'MM_AttServiceReqData_U', 'MM_AttServiceRequest_U', 'MM_UnsuccServiceReq_U', 'uplinkSndcpOctetReceivedMode', 'nbrOfUnknownAnswerInSgsn', 'nbrOfWhiteAnswerInSgsn', 'nbrOfBlackAnswerInSgsn', 'nbrOfGreyAnswerInSgsn', 'anbrOfUnknownAnswerInSgsn', 'nbrOfCheckIMEIRequest', 'MM_AttGprsAttach_G', 'MM_AttGprsDetachMs_G', 'MM_AttGprsDetachSgsn_G', 'MM_AttInterSgsnRaUpdate_G', 'MM_AttIntraSgsnRaUpdate_G', 'MM_AttPsPagingProcGb', 'MM_SuccGprsAttach_G', 'MM_SuccInterSgsnRaUpdate_G', 'MM_SuccIntraSgsnRaUpdate_G', 'MM_SuccPsPagingProcGb', 'MM_AttGprsAttach_U', 'MM_AttGprsDetachMs_U', 'MM_AttGprsDetachSgsn_U', 'MM_AttInterSgsnRaUpdate_U', 'MM_AttIntraSgsnRaUpdate_U', 'MM_AttPsPagingProcGb', 'MM_SuccGprsAttach_U', 'MM_SuccInterSgsnRaUpdate_U', 'MM_SuccIntraSgsnRaUpdate_U','attAuthInSgsn', 'downlinkSndcpNpduSent', 'downlinkSndcpOctetSent', 'errLlcFramesDetectedBySgsn', 'gprsSmSgsnDeactivations', 'gprsSmSgsnUnsuccessfulActivations', 'gprsSmSgsnUnsuccessfulModifications', 'gsnAutomaticConnectionRestarts', 'gsnManualConnectionRestarts', 'gsnOverloadProtectionIgnoredExistingConnections', 'gsnOverloadProtectionIgnoredNewConnections', 'nbrLlcFramesReceived', 'nbrLlcFramesSent', 'succAuthInSgsn', 'uplinkSndcpNpduReceived'],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'MM_nonindexed',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE           => 'DATALINE_WHERE',
        RULE_DESC           => 'DATALINE example',
        INPUT_FILE_DESCRIPTION       => ['^MM_nonindexed-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
        PRODUCE_PIF => "True",
        OUTPUT_FORMAT => 0,
        COUNTER_NAMES  =>
             [
              {
                   'COUNTER_NAME'  => 'MM_NbrActAttachedSub_G',
                   'KEEP_WHERE'  => [ '\d+' ],
              },
              {
                   'COUNTER_NAME'  => 'MM_NbrActAttachedSub_U',
                   'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg MM data',
        INPUT_FILE_DESCRIPTION    => '^(MM_nonindexed-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id)],
        PEG_COUNTERS         => {
            'MM_Succ\w+_U' => '4294967295',
            'MM_Unsucc\w+_G' => '4294967295',
            'MM_Att\w+' => '4294967295',
		        'att\w+' => '4294967295',
		        'gprs\w+' => '4294967295',
		        'succ\w+' => '4294967295',
		        'unsucc\w+' => '4294967295',
            'discarded\w+' => '4294967295',
        },

 },
 
####---------------------------Block SM_nonindexed -----------------------------------------###
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for SM_nonindexed Block for files from upl-*.pif',
        INPUT_FILE_DESCRIPTION => ['^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'SM_nonindexed',
        REDUNDANT_DATA_COUNTERS => ['attGprsDetachSgsnUmts', 'succGprsAttachUmts', 'attGprsAttachUmts', 'attPacketSwitchingPagingUmts', 'attGprsDetachMsUmts', 'discardedCombiRaUpdate', 'discardedCombiAttach', 'unsuccPacketSwitchingPagingUmts', 'succGprsDetachSgsnUmts', 'attInterSgsnRaUpdateUmts', 'succInterSgsnRaUpdateUmts', 'unsuccGprsAttachUmts', 'discardedGprsAttach', 'succPacketSwitchingPagingUmts', 'attIntraSgsnRaUpdateUmts', 'discardedRaUpdate', 'succIntraSgsnRaUpdateUmts', 'discardedDetach', 'succGprsAttach', 'succIntraSgsnRaUpdate', 'moid', 'nbrOfWhiteAnswerInSgsn', 'gsnAutomaticConnectionRestarts', 'nbrOfSubStandby', 'succInterSgsnRaUpdate', 'uplinkSndcpOctetReceivedMode', 'attAuthInSgsn', 'nbrOfUnknownAnswerInSgsn', 'attCombiAttach', 'uplinkSndcpNpduReceived', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnRejectedByAdmissionControl', 'attImsiDetachMs', 'succGprsDetachSgsn', 'succAuthInSgsn', 'nbrLlcFramesSent', 'nbrLlcFramesReceived', 'downlinkSndcpNpduSent', 'succCombiAttach', 'attCombiDetachMs', 'nbrOfBlackAnswerInSgsn', 'attPacketSwitchingPaging', 'gprsMmSgsnUnsuccessfulPagingProcedures', 'nbrOfGreyAnswerInSgsn', 'gsnOverloadProtectionIgnoredNewConnections', 'gsnManualConnectionRestarts', 'attGprsDetachMs', 'downlinkSndcpOctetSent', 'gsnOverloadProtectionIgnoredExistingConnections', 'nbrOfSubReady', 'unsuccPacketSwitchingPaging', 'attImsiAttach', 'gprsMmSgsnPagingProcedures', 'attIntraSgsnRaUpdate', 'attGprsAttach', 'nbrOfCheckIMEIRequest', 'attGprsDetachSgsn', 'gprsMmSgsnSuccessfulPagingProcedures', 'subscribersInTransitionalState', 'succImsiAttach', 'attInterSgsnRaUpdate', 'errLlcFramesDetectedBySgsn'],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'SM_nonindexed',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for SM_nonindexed Block for files from SM_nonindexed-*.pif',
        INPUT_FILE_DESCRIPTION => ['^SM_nonindexed-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'SM_nonindexed',
        REDUNDANT_DATA_COUNTERS => ['Record_measurement_count', 'SM_AttActPdpContextRa_G', 'SM_AttActPdpContextRa_U', 'SM_SuccActPdpContextRa_G', 'SM_SuccActPdpContextRa_U', 'succGprsAttach', 'succIntraSgsnRaUpdate', 'moid', 'nbrOfWhiteAnswerInSgsn', 'gsnAutomaticConnectionRestarts', 'nbrOfSubStandby', 'succInterSgsnRaUpdate', 'uplinkSndcpOctetReceivedMode', 'attAuthInSgsn', 'nbrOfUnknownAnswerInSgsn', 'attCombiAttach', 'uplinkSndcpNpduReceived', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnRejectedByAdmissionControl', 'attImsiDetachMs', 'succGprsDetachSgsn', 'succAuthInSgsn', 'nbrLlcFramesSent', 'nbrLlcFramesReceived', 'downlinkSndcpNpduSent', 'succCombiAttach', 'attCombiDetachMs', 'nbrOfBlackAnswerInSgsn', 'attPacketSwitchingPaging', 'gprsMmSgsnUnsuccessfulPagingProcedures', 'nbrOfGreyAnswerInSgsn', 'gsnOverloadProtectionIgnoredNewConnections', 'gsnManualConnectionRestarts', 'attGprsDetachMs', 'downlinkSndcpOctetSent', 'gsnOverloadProtectionIgnoredExistingConnections', 'nbrOfSubReady', 'unsuccPacketSwitchingPaging', 'attImsiAttach', 'gprsMmSgsnPagingProcedures', 'attIntraSgsnRaUpdate', 'attGprsAttach', 'nbrOfCheckIMEIRequest', 'attGprsDetachSgsn', 'gprsMmSgsnSuccessfulPagingProcedures', 'subscribersInTransitionalState', 'succImsiAttach', 'attInterSgsnRaUpdate', 'errLlcFramesDetectedBySgsn'],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'SM_nonindexed-2',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg SM data',
        INPUT_FILE_DESCRIPTION    => '^(SM_nonindexed-#-).*-#-.*-#-(.*)-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id)],
        PEG_COUNTERS         => {
            'SM_Succ\w+' => '4294967295',
            'SM_Unsucc\w+' => '4294967295',
            'SM_Att\w+' => '4294967295',
            'gprsSm\w+' => '4294967295',
            'discarded\w+' => '4294967295',
            'SM_Pdp\w+' => '4294967295',            
        },

},

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg SM data',
        INPUT_FILE_DESCRIPTION    => '^(SM_nonindexed-2-#-).*-#-.*-#-(.*)-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id)],
        PEG_COUNTERS         => {
            'SM_Succ\w+' => '4294967295',
            'SM_Unsucc\w+' => '4294967295',
            'SM_Att\w+' => '4294967295',
            'gprsSm\w+' => '4294967295',
            'discarded\w+' => '4294967295',
            'SM_Pdp\w+' => '4294967295',            
        },

},  

####---------------------------Block SM_Index -----------------------------------------###
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for SM_Index Block',
        INPUT_FILE_DESCRIPTION => ['^SM_nonindexed-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'SM_Index',
        REDUNDANT_DATA_COUNTERS => [ 'SM_AttDeactPdpContextSgsnCC39_U', 'SM_SuccModPdpContextSgsn_U', 'SM_SuccUpdPdpContextGgsn_U', 'SM_AttDeactPdpContextMs_U', 'SM_AttActSecondPdpContext_U', 'SM_AttActPdpContextDyn_U', 'SM_AttRabAssignment', 'SM_SuccDeactPdpContextMs_G', 'SM_UnsuccActPdpContextCC29_G', 'SM_PdpContextsLost_U', 'SM_NbrActPdpContext_G', 'SM_AttDeactPdpContextSgsnCC38_G', 'SM_SuccDeactPdpContextGgsn_G', 'SM_SuccActPdpContext_G', 'SM_UnsuccActPdpContextCC29_U', 'SM_SuccDeactPdpContextMs_U', 'SM_NbrActPdpContext_U', 'SM_NbrActivePdpPerSgsn_G', 'SM_AttDeactPdpContextSgsnCC38_U', 'SM_AttDeactPdpContextSgsn_G', 'SM_SuccRabAssignment', 'SM_SuccDeactPdpContextGgsn_U', 'SM_SuccActPdpContext_U', 'SM_AttUpdPdpContextSgsn_G', 'SM_NbrActivePdpPerSgsn_U', 'SM_AttDeactPdpContextSgsn_U', 'SM_AttRabModPS', 'SM_UnsuccActPdpContextCC32_33_G', 'SM_AttUpdPdpContextSgsn_U', 'SM_UnsuccActPdpContextCC27_28_G', 'SM_SuccActSecondPdpContext_G', 'SM_SuccUpdPdpContextSgsn_G', 'SM_SuccModPdpContextMs_G', 'SM_UnsuccActPdpContextCC32_33_U', 'SM_UnsuccActPdpContextCC27_28_U', 'SM_SuccActSecondPdpContext_U', 'SM_SuccUpdPdpContextSgsn_U', 'SM_SuccModPdpContextMs_U', 'SM_AttActPdpContext_G', 'SM_SuccActPdpContextSgsnHome_G', 'SM_AttModPdpContextMs_G', 'SM_AttDeactPdpContextGgsn_G', 'SM_AttModPdpContextSgsn_G', 'SM_AttUpdPdpContextGgsn_G', 'SM_SuccDeactPdpContextSgsn_G', 'SM_AttActPdpContext_U', 'SM_SuccActPdpContextSgsnHome_U', 'SM_UnsuccActPdpContextCC26_G', 'SM_AttModPdpContextMs_U', 'SM_AttDeactPdpContextGgsn_U', 'SM_AttActPdpContextSgsnHome_G', 'SM_AttModPdpContextSgsn_U', 'SM_SuccActPdpContextDyn_G', 'SM_AttUpdPdpContextGgsn_U', 'SM_SuccDeactPdpContextSgsn_U', 'SM_UnsuccActPdpContextCC38_G', 'SM_UnsuccActPdpContextCC26_U', 'SM_AttDeactPdpContextSgsnCC39_G', 'SM_SuccModPdpContextSgsn_G', 'SM_SuccUpdPdpContextGgsn_G', 'SM_AttDeactPdpContextMs_G', 'Record_measurement_count', 'SM_AttActPdpContextSgsnHome_U', 'SM_AttActPdpContextDyn_G', 'SM_SuccActPdpContextDyn_U', 'SM_UnsuccActPdpContextCC38_U', 'SM_AttActSecondPdpContext_G', 'SM_PdpContextsLost_G' ],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid Network_Id) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'SM_Index',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
         RULE_TYPE           => 'DATALINE_WHERE',
         RULE_DESC           => 'DATALINE_WHERE to removed records without moid ',
	       INPUT_FILE_DESCRIPTION       => '^SM_Index-#-.*-#-.*-#-(.*)-#-.*-#-J.pif',
         PRODUCE_PIF => 'True',
         OUTPUT_FORMAT => 0,
         COUNTER_NAMES  => [
                     {
                COUNTER_NAME  => 'moid',
                KEEP_WHERE  => [ '.+' ],
                REMOVE_WHERE  => [ ],
                     },
                 ],
         OUTPUT_BLOCK_NAME => 'SM_Index',
},

{
         RULE_TYPE        => 'UNPEGGER',
         RULE_DESC        => 'Unpeg SM data',
         INPUT_FILE_DESCRIPTION    => '^(SM_Index-#-).*-#-.*-#-(.*)-#-.*-#-J-#-DW.pif',
         INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
         PEG_FILENAME_PREFIX       => 'SAVED',
         UNPEG_FILENAME_PREFIX     => 'UNPEG',
         UNPEG_FILE_TYPE           => 'HEADER',
         OUTPUT_FORMAT             => 'LIF_Writer',
         PRODUCE_PIF               => 0,
         KEEP_RAW_GRANULARITY      => 'TRUE',
         MAX_PEG_PIF_AGE           => 'DURATION*4+60',
         CALCULATE_ROLLOVER        => 'True',
         DEFAULT_NULL_VALUE        => '',
         DATETIME_COUNTERS         => {
             STARTDATE => 'mts_Date',
             STARTTIME => 'mts_Time',
             DURATION  => 'gp',
             FORMAT    => 'seconds',
         },
         COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
         PEG_COUNTERS         => {
             'SM_Succ\w+' => '4294967295',
             'SM_Att\w+' => '4294967295',
         },
},

#####---------------------------Block SMS  -----------------------------------------###
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg SMS data',
        INPUT_FILE_DESCRIPTION    => '^(SMS-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'SMS\w+_U' => '4294967295',
            'SMS\w+_G' => '4294967295',
        },

 },

#### ------------------------------ block Overload ----------------------------####
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for Overload block from upl* pif',
        INPUT_FILE_DESCRIPTION => ['^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'Overload',
        REDUNDANT_DATA_COUNTERS => [ 'attInterSgsnRaUpdate', 'errLlcFramesDetectedBySgsn', 'attGprsDetachSgsnUmts', 'attGprsAttachUmts', 'succIntraSgsnRaUpdate', 'nbrOfSubStandby', 'succInterSgsnRaUpdate', 'uplinkSndcpOctetReceivedMode', 'unsuccPacketSwitchingPagingUmts', 'uplinkSndcpNpduReceived', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnRejectedByAdmissionControl', 'attImsiDetachMs', 'succGprsDetachSgsn', 'discardedPayloadPacket', 'succPacketSwitchingPagingUmts', 'succAuthInSgsn', 'succGprsAttachUmts', 'attPacketSwitchingPagingUmts', 'nbrOfBlackAnswerInSgsn', 'attPacketSwitchingPaging', 'nbrOfGreyAnswerInSgsn', 'downlinkSndcpOctetSent', 'nbrOfSubReady', 'attImsiAttach', 'gprsMmSgsnPagingProcedures', 'attIntraSgsnRaUpdate', 'gprsSmSgsnUnsuccessfulModifications', 'attIntraSgsnRaUpdateUmts', 'subscribersInTransitionalState', 'discardedRaUpdate', 'errLlcFramesDetectedBySgsn|attInterSgsnRaUpdate', 'succGprsAttach', 'nbrOfWhiteAnswerInSgsn', 'gsnAutomaticConnectionRestarts', 'attGprsDetachMsUmts', 'attAuthInSgsn', 'attInterSgsnRaUpdateUmts', 'nbrOfUnknownAnswerInSgsn', 'attCombiAttach', 'discardedGprsAttach', 'succIntraSgsnRaUpdateUmts', 'downlinkSndcpNpduSent', 'gprsSmSgsnDeactivations', 'nbrLlcFramesReceived', 'nbrLlcFramesSent', 'succCombiAttach', 'attCombiDetachMs', 'gprsSmSgsnUnsuccessfulActivations', 'discardedCombiRaUpdate', 'Network_Id', 'attGprsDetachMs', 'gsnManualConnectionRestarts', 'discardedSessionMgmnt', 'discardedCombiAttach', 'succGprsDetachSgsnUmts', 'unsuccPacketSwitchingPaging', 'succInterSgsnRaUpdateUmts', 'unsuccGprsAttachUmts', 'attGprsAttach', 'nbrOfCheckIMEIRequest', 'attGprsDetachSgsn', 'gprsMmSgsnSuccessfulPagingProcedures', 'succImsiAttach', 'discardedDetach'], 
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'Overload',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for Overload block from sgn* pif',
        INPUT_FILE_DESCRIPTION => ['^gsn-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'Overload',
        REDUNDANT_DATA_COUNTERS => [ ], 
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'OverloadGSN',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg Overload data',
        INPUT_FILE_DESCRIPTION    => ['^(Overload-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
                    '^(OverloadGSN-#-.*)-#-.*-#-.*-#-.*-#-J.pif'],
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'gsnOverload\w+' => '4294967295',
        },
},

####---------------------------Block Security / SEC -----------------------------------------###
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for SEC block ',
        INPUT_FILE_DESCRIPTION => ['^Security-#-(.*-#-.*-#-.*)-#-.*-#-I.pif',
				   '^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'Security',
        REDUNDANT_DATA_COUNTERS => [ 'attGprsAttachUmts', 'attGprsDetachMsUmts', 'attGprsDetachSgsnUmts', 'attInterSgsnRaUpdateUmts', 'attIntraSgsnRaUpdateUmts', 'attPacketSwitchingPagingUmts', 'discardedCombiAttach', 'discardedCombiRaUpdate', 'discardedDetach', 'discardedGprsAttach', 'discardedPayloadPacket', 'discardedRaUpdate', 'discardedSessionMgmnt', 'succGprsAttachUmts', 'succGprsDetachSgsnUmts', 'succInterSgsnRaUpdateUmts', 'succIntraSgsnRaUpdateUmts', 'succPacketSwitchingPagingUmts', 'unsuccGprsAttachUmts', 'unsuccPacketSwitchingPagingUmts', 'SM_SuccActPdpContextRa_U', 'SM_SuccActPdpContextRa_G', 'SM_AttActPdpContextRa_U', 'SM_AttActPdpContextRa_G', 'nbrOfUnknownAnswerInSgsn', 'nbrOfWhiteAnswerInSgsn', 'nbrOfBlackAnswerInSgsn', 'nbrOfCheckIMEIRequest', 'nbrOfGreyAnswerInSgsn', 'attCombiAttach', 'attCombiDetachMs', 'attGprsAttach', 'attGprsDetachMs', 'attGprsDetachSgsn', 'attImsiAttach', 'attImsiDetachMs', 'attInterSgsnRaUpdate', 'attIntraSgsnRaUpdate', 'attPacketSwitchingPaging', 'downlinkSndcpNpduSent', 'downlinkSndcpOctetSent', 'errLlcFramesDetectedBySgsn', 'gprsMmSgsnPagingProcedures', 'gprsMmSgsnRejectedByAdmissionControl', 'gprsMmSgsnSuccessfulPagingProcedures', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnUnsuccessfulPagingProcedures', 'gprsSmSgsnDeactivations', 'gprsSmSgsnUnsuccessfulActivations', 'gprsSmSgsnUnsuccessfulModifications', 'gsnAutomaticConnectionRestarts', 'gsnManualConnectionRestarts', 'gsnOverloadProtectionIgnoredExistingConnections', 'gsnOverloadProtectionIgnoredNewConnections', 'nbrLlcFramesReceived', 'nbrLlcFramesSent', 'nbrOfSubReady', 'nbrOfSubStandby', 'subscribersInTransitionalState', 'succCombiAttach', 'succGprsAttach', 'succGprsDetachSgsn', 'succImsiAttach', 'succInterSgsnRaUpdate', 'succIntraSgsnRaUpdate', 'unsuccPacketSwitchingPaging', 'uplinkSndcpNpduReceived', 'uplinkSndcpOctetReceivedMode'],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'Security',
        REDUNDANT_HEADER_COUNTERS => [],
},
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg security data',
        INPUT_FILE_DESCRIPTION    => '^(Security-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'SEC_\w+' => '4294967295',
            'att\w+' => '4294967295',
            'succ\w+' => '4294967295',
        },
},
 
##### ------------------------------ block EQUIP ----------------------------####
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for EQUIP block',
        INPUT_FILE_DESCRIPTION => ['^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'EQUIP',
        REDUNDANT_DATA_COUNTERS => ['succGprsAttachUmts', 'succGprsDetachSgsnUmts', 'succInterSgsnRaUpdateUmts', 'succIntraSgsnRaUpdateUmts', 'succPacketSwitchingPagingUmts', 'unsuccGprsAttachUmts', 'unsuccPacketSwitchingPagingUmts', 'attGprsAttachUmts', 'attGprsDetachMsUmts', 'attGprsDetachSgsnUmts', 'attInterSgsnRaUpdateUmts', 'attIntraSgsnRaUpdateUmts', 'attPacketSwitchingPagingUmts', 'discardedCombiAttach', 'discardedCombiRaUpdate', 'discardedDetach', 'discardedGprsAttach', 'discardedPayloadPacket', 'discardedRaUpdate', 'discardedSessionMgmnt', 'SM_SuccActPdpContextRa_U', 'SM_SuccActPdpContextRa_G', 'SM_AttActPdpContextRa_U', 'SM_AttActPdpContextRa_G', 'succGprsAttach', 'succIntraSgsnRaUpdate', 'gsnAutomaticConnectionRestarts', 'nbrOfSubStandby', 'succInterSgsnRaUpdate', 'uplinkSndcpOctetReceivedMode', 'attAuthInSgsn', 'attCombiAttach', 'uplinkSndcpNpduReceived', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnRejectedByAdmissionControl', 'attImsiDetachMs', 'succGprsDetachSgsn', 'succAuthInSgsn', 'nbrLlcFramesSent', 'nbrLlcFramesReceived', 'gprsSmSgsnDeactivations', 'downlinkSndcpNpduSent', 'succCombiAttach', 'attCombiDetachMs', 'attPacketSwitchingPaging', 'gprsSmSgsnUnsuccessfulActivations', 'gprsMmSgsnUnsuccessfulPagingProcedures', 'gsnOverloadProtectionIgnoredNewConnections', 'gsnManualConnectionRestarts', 'attGprsDetachMs', 'downlinkSndcpOctetSent', 'gsnOverloadProtectionIgnoredExistingConnections', 'nbrOfSubReady', 'unsuccPacketSwitchingPaging', 'attImsiAttach', 'Record_measurement_count', 'gprsMmSgsnPagingProcedures', 'attIntraSgsnRaUpdate', 'attGprsAttach', 'attGprsDetachSgsn', 'gprsMmSgsnSuccessfulPagingProcedures', 'gprsSmSgsnUnsuccessfulModifications', 'subscribersInTransitionalState', 'succImsiAttach', 'attInterSgsnRaUpdate', 'errLlcFramesDetectedBySgsn' ],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'Equip',
        REDUNDANT_HEADER_COUNTERS => [],
},
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg EQUIP data',
        INPUT_FILE_DESCRIPTION    => '^(Equip-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'nbrOf\w+' => '4294967295',
			
        },
 },

##### ------------------------------ block LLC ----------------------------####
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for LLC block',
        INPUT_FILE_DESCRIPTION => ['^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'LLC',
        REDUNDANT_DATA_COUNTERS => ['attGprsAttachUmts', 'attGprsDetachMsUmts', 'attGprsDetachSgsnUmts', 'attInterSgsnRaUpdateUmts', 'attIntraSgsnRaUpdateUmts', 'attPacketSwitchingPagingUmts', 'discardedCombiAttach', 'discardedCombiRaUpdate', 'discardedDetach', 'discardedGprsAttach', 'discardedPayloadPacket', 'discardedRaUpdate', 'discardedSessionMgmnt', 'succGprsAttachUmts', 'succGprsDetachSgsnUmts', 'succInterSgsnRaUpdateUmts', 'succIntraSgsnRaUpdateUmts', 'succPacketSwitchingPagingUmts', 'unsuccGprsAttachUmts', 'unsuccPacketSwitchingPagingUmts', 'SM_SuccActPdpContextRa_U', 'SM_SuccActPdpContextRa_G', 'SM_AttActPdpContextRa_U', 'SM_AttActPdpContextRa_G', 'nbrOfBlackAnswerInSgsn', 'nbrOfCheckIMEIRequest', 'nbrOfGreyAnswerInSgsn', 'nbrOfUnknownAnswerInSgsn', 'nbrOfWhiteAnswerInSgsn', 'succGprsAttach', 'succIntraSgsnRaUpdate', 'gsnAutomaticConnectionRestarts', 'nbrOfSubStandby', 'succInterSgsnRaUpdate', 'uplinkSndcpOctetReceivedMode', 'attAuthInSgsn', 'attCombiAttach', 'uplinkSndcpNpduReceived', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnRejectedByAdmissionControl', 'attImsiDetachMs', 'succGprsDetachSgsn', 'succAuthInSgsn', 'gprsSmSgsnDeactivations', 'downlinkSndcpNpduSent', 'succCombiAttach', 'attCombiDetachMs', 'attPacketSwitchingPaging', 'gprsSmSgsnUnsuccessfulActivations', 'gprsMmSgsnUnsuccessfulPagingProcedures', 'gsnOverloadProtectionIgnoredNewConnections', 'gsnManualConnectionRestarts', 'attGprsDetachMs', 'downlinkSndcpOctetSent', 'gsnOverloadProtectionIgnoredExistingConnections', 'nbrOfSubReady', 'unsuccPacketSwitchingPaging', 'attImsiAttach', 'Record_measurement_count', 'gprsMmSgsnPagingProcedures', 'attIntraSgsnRaUpdate', 'attGprsAttach', 'attGprsDetachSgsn', 'gprsMmSgsnSuccessfulPagingProcedures', 'gprsSmSgsnUnsuccessfulModifications', 'subscribersInTransitionalState', 'succImsiAttach', 'attInterSgsnRaUpdate'],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'LLC',
        REDUNDANT_HEADER_COUNTERS => [],
},
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg LLC data',
        INPUT_FILE_DESCRIPTION    => '^(LLC-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'nbrLlc\w+' => '4294967295',
            'errLlc\w+' => '4294967295',
			
        },
 },


#### ------------------------------ block ISP ----------------------------####
{
        RULE_TYPE        => 'JOIN',
        RULE_DESC        => 'Join files for ISP block',
        INPUT_FILE_DESCRIPTION    => ['^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME         => 'ISP',
        REDUNDANT_DATA_COUNTERS   => ['SM_SuccActPdpContextRa_U', 'SM_SuccActPdpContextRa_G', 'SM_AttActPdpContextRa_U', 'SM_AttActPdpContextRa_G', 'discardedCombiAttach', 'discardedGprsAttach', 'discardedCombiRaUpdate', 'discardedRaUpdate', 'discardedDetach','succPacketSwitchingPagingUmts', 'unsuccPacketSwitchingPagingUmts', 'attPacketSwitchingPagingUmts', 'succIntraSgsnRaUpdateUmts', 'attIntraSgsnRaUpdateUmts', 'succInterSgsnRaUpdateUmts', 'attInterSgsnRaUpdateUmts', 'succGprsDetachSgsnUmts', 'attGprsDetachMsUmts', 'attGprsDetachSgsnUmts', 'succGprsAttachUmts', 'unsuccGprsAttachUmts', 'attGprsAttachUmts', 'nbrLlcFramesSent', 'nbrLlcFramesReceived', 'errLlcFramesDetectedBySgsn', 'nbrOfBlackAnswerInSgsn', 'nbrOfCheckIMEIRequest', 'nbrOfGreyAnswerInSgsn', 'nbrOfUnknownAnswerInSgsn', 'nbrOfWhiteAnswerInSgsn', 'succGprsAttach', 'succIntraSgsnRaUpdate', 'nbrOfSubStandby', 'succInterSgsnRaUpdate', 'uplinkSndcpOctetReceivedMode', 'attAuthInSgsn', 'attCombiAttach', 'uplinkSndcpNpduReceived', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnRejectedByAdmissionControl', 'attImsiDetachMs', 'succGprsDetachSgsn', 'succAuthInSgsn', 'gprsSmSgsnDeactivations', 'downlinkSndcpNpduSent', 'succCombiAttach', 'attCombiDetachMs', 'attPacketSwitchingPaging', 'gprsSmSgsnUnsuccessfulActivations', 'gprsMmSgsnUnsuccessfulPagingProcedures', 'gsnOverloadProtectionIgnoredNewConnections', 'attGprsDetachMs', 'downlinkSndcpOctetSent', 'gsnOverloadProtectionIgnoredExistingConnections', 'nbrOfSubReady', 'unsuccPacketSwitchingPaging', 'attImsiAttach', 'Record_measurement_count', 'gprsMmSgsnPagingProcedures', 'attIntraSgsnRaUpdate', 'attGprsAttach', 'attGprsDetachSgsn', 'gprsMmSgsnSuccessfulPagingProcedures', 'gprsSmSgsnUnsuccessfulModifications', 'subscribersInTransitionalState', 'succImsiAttach', 'attInterSgsnRaUpdate', 'errLlcFramesDetectedBySgsn' ],
        PRODUCE_PIF               => 'True',
        PRODUCE_LIF               => 0,
        COUNTERS_TO_JOIN_ON       => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START     => 'ISP',
        REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE        => 'JOIN',
        RULE_DESC        => 'Join files for ISP Block, for MM_AttachedLost_G and MM_AttachedLost_U ',
        INPUT_FILE_DESCRIPTION    => ['^MM-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME         => 'ISP',
        REDUNDANT_DATA_COUNTERS   => [ 'discardedCombiAttach', 'discardedCombiRaUpdate', 'discardedDetach', 'discardedGprsAttach', 'discardedPayloadPacket', 'discardedRaUpdate', 'discardedSessionMgmnt', 'moid', 'Record_measurement_count', 'MM_AttPsPagingProcIu', 'MM_AttGprsDetachMs_G', 'MM_AttNormalIntraSgsnRaUpdate_G', 'MM_AttIntraSgsnRaUpdate_U', 'MM_SuccCombiInterSgsnRaUpdate_G', 'MM_AttGprsDetachMs_U', 'MM_AttNormalIntraSgsnRaUpdate_U', 'MM_AttImsiCombiIntraSgsnRaUpdate_G', 'MM_AttGprsAttach_G', 'MM_AttCombiIntraSgsnRaUpdate_G', 'MM_SuccPsPagingProcIu', 'MM_SuccInterSgsnRaUpdate_G', 'MM_AttGprsAttach_U', 'MM_AttPsPagingProcGb', 'MM_SuccInterSgsnRaUpdate_U', 'MM_NbrActAttachedSubRA_G', 'MM_AttGprsDetachSgsn_G', 'MM_SuccGprsDetachSgsn_G', 'MM_NbrActAttachedSubRA_U', 'MM_SuccCombiIntraSgsnRaUpdate_G', 'MM_SuccPsPagingProcGb', 'MM_SuccGprsAttach_G', 'MM_SuccFirstPsPagingIu', 'MM_AttGprsDetachSgsn_U', 'MM_SuccGprsDetachSgsn_U', 'MM_AttInterSgsnRaUpdate_G', 'MM_SuccIntraSgsnRaUpdate_G', 'MM_SuccGprsAttach_U', 'MM_SuccNormalIntraSgsnRaUpdate_G', 'MM_AttInterSgsnRaUpdate_U', 'MM_SuccIntraSgsnRaUpdate_U', 'MM_SuccNormalIntraSgsnRaUpdate_U', 'MM_AttImsiCombiInterSgsnRaUpdate_G', 'MM_AttCombiInterSgsnRaUpdate_G', 'MM_UnsuccAttachCC11_G', 'MM_SuccFirstPsPagingGb', 'MM_UnsuccISRAUCSPSCoord_U', 'MM_UnsuccAttachCC11_U', 'MM_AttIntraSgsnRaUpdate_G', 'MM_UnsuccAttachCSPSCoord_U', 'MM_UnsuccInterSgsnRauCC14_U', 'MM_UnsuccAttachCC15_U', 'MM_UnsuccIntraSgsnRauCC14_G', 'MM_nbrDetachedInactiveSub_G', 'MM_UnsuccServiceReq_U', 'MM_UnsuccAttachCC22_G', 'MM_NbrVisitingNatSub_G', 'MM_UnsuccAttachCC7_G', 'MM_UnsuccAttachCC14_G', 'MM_UnsuccIntraSgsnRauCC14_U', 'MM_AttDetachInactiveSub_G', 'MM_UnsuccAttachCC22_U', 'MM_UnsuccInterSgsnRauCC17_G', 'MM_UnsuccAttachCC7_U', 'MM_NbrVisitingNatSub_U', 'MM_UnsuccAttachCC14_U', 'MM_NbrCamelSub_G', 'MM_AttServiceReqData_U', 'MM_UnsuccInterSgsnRauCC17_U', 'MM_UnsuccAttachCC13_G', 'MM_NbrCamelSub_U', 'MM_UnsuccIntraSgsnRauCC17_G', 'MM_UnsuccAttachCC17_G', 'MM_UnsuccAttachCC13_U', 'MM_UnsuccIntraSgsnRauCC17_U', 'MM_UnsuccAttachCC17_U', 'MM_NbrVisitingForeign_G', 'MM_AttServiceRequest_U', 'MM_NbrVisitingForeign_U', 'MM_NbrHomeSub_G', 'MM_NbrSubPmmConnected', 'MM_UnsuccInterSgsnRauCC9_G', 'MM_NbrActAttachedSub_G', 'MM_NbrHomeSub_U', 'MM_UnsuccAttachCC8_G', 'MM_UnsuccInterSgsnRauCC14_G', 'MM_UnsuccAttachCC15_G', 'MM_UnsuccInterSgsnRauCC9_U', 'MM_NbrActAttachedSub_U', 'MM_UnsuccAttachCC8_U'],
        PRODUCE_PIF               => 'True',
        PRODUCE_LIF               => 0,
        COUNTERS_TO_JOIN_ON       => [qw(Node_Id Region_Id Network_Id) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START     => 'ISP-2',
        REDUNDANT_HEADER_COUNTERS => [],
},


{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg ISP data',
        INPUT_FILE_DESCRIPTION    => '^(ISP-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS              => {
            'gsnManualConnectionRestarts' => '4294967295',
            'gsnAutomaticConnectionRestarts' => '4294967295',
        },
},

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg ISP data',
        INPUT_FILE_DESCRIPTION    => '^(ISP-2-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id)],
        PEG_COUNTERS              => {
            'MM_AttachedLost_G' => '4294967295',
            'MM_AttachedLost_U' => '4294967295',
        },
},

##### ------------------------------ block SNDCP ----------------------------####
{
        RULE_TYPE => 'JOIN',
        RULE_DESC => 'Join files for SNDCP block',
        INPUT_FILE_DESCRIPTION => ['^upl-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME => 'SNDCP',
        REDUNDANT_DATA_COUNTERS => [ 'attGprsDetachSgsnUmts', 'succGprsAttachUmts', 'attGprsAttachUmts', 'attPacketSwitchingPagingUmts', 'attGprsDetachMsUmts', 'discardedCombiRaUpdate', 'discardedSessionMgmnt', 'discardedCombiAttach', 'unsuccPacketSwitchingPagingUmts', 'succGprsDetachSgsnUmts', 'attInterSgsnRaUpdateUmts', 'succInterSgsnRaUpdateUmts', 'unsuccGprsAttachUmts', 'discardedPayloadPacket', 'discardedGprsAttach', 'succPacketSwitchingPagingUmts', 'attIntraSgsnRaUpdateUmts', 'succIntraSgsnRaUpdateUmts', 'discardedRaUpdate', 'discardedDetach', 'SM_SuccActPdpContextRa_U', 'SM_SuccActPdpContextRa_G', 'SM_AttActPdpContextRa_U', 'SM_AttActPdpContextRa_G', 'gsnManualConnectionRestarts', 'gsnAutomaticConnectionRestarts', 'nbrLlcFramesSent', 'nbrLlcFramesReceived', 'errLlcFramesDetectedBySgsn', 'nbrOfBlackAnswerInSgsn', 'nbrOfCheckIMEIRequest', 'nbrOfGreyAnswerInSgsn', 'nbrOfUnknownAnswerInSgsn', 'nbrOfWhiteAnswerInSgsn', 'succGprsAttach', 'succIntraSgsnRaUpdate', 'nbrOfSubStandby', 'succInterSgsnRaUpdate', 'attAuthInSgsn', 'attCombiAttach', 'gprsMmSgsnUnsuccessfulAttachRequests', 'gprsMmSgsnRejectedByAdmissionControl', 'attImsiDetachMs', 'succGprsDetachSgsn', 'succAuthInSgsn', 'gprsSmSgsnDeactivations', 'succCombiAttach', 'attCombiDetachMs', 'attPacketSwitchingPaging', 'gprsSmSgsnUnsuccessfulActivations', 'gprsMmSgsnUnsuccessfulPagingProcedures', 'gsnOverloadProtectionIgnoredNewConnections', 'attGprsDetachMs', 'gsnOverloadProtectionIgnoredExistingConnections', 'nbrOfSubReady', 'unsuccPacketSwitchingPaging', 'attImsiAttach', 'Record_measurement_count', 'gprsMmSgsnPagingProcedures', 'attIntraSgsnRaUpdate', 'attGprsAttach', 'attGprsDetachSgsn', 'gprsMmSgsnSuccessfulPagingProcedures', 'gprsSmSgsnUnsuccessfulModifications', 'subscribersInTransitionalState', 'succImsiAttach', 'attInterSgsnRaUpdate', 'errLlcFramesDetectedBySgsn' ],
        PRODUCE_PIF => 'True',
        PRODUCE_LIF => 0,
        COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START => 'SNDCP',
        REDUNDANT_HEADER_COUNTERS => [],
},
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg SNDCP data',
        INPUT_FILE_DESCRIPTION    => '^(SNDCP-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'uplinkSndcp\w+' => '4294967295',
            'downlinkSndcp\w+' => '4294967295',
			
        },
 },

#### ----------------------------Block CAMEL / CAM  ----------------------------------------###
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg CAM data',
        INPUT_FILE_DESCRIPTION    => '^(CAMEL-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'CAM_\w+' => '4294967295',
        },

 },

####---------------------------Block Qos  -----------------------------------------###
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg Qos data',
        INPUT_FILE_DESCRIPTION    => '^(QoS-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'QoS_DL\w+' => '4294967295',
            'QoS_Att\w+' => '4294967295',
            'QoS_Gua\w+' => '4294967295',
            'QoS_UL\w+' => '4294967295',
        },

},
 
#### ------------------------Block FRWan --------------------------------------###
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg FRWan data',
        INPUT_FILE_DESCRIPTION => '^(FRWan-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
		     'frWanLmiErrors' => '4294967295',
		     'frWanLmiTimeouts' => '4294967295',
		     'frWanLmiWanFlows' => '4294967295',
		     'frWanRxAsynchs' => '4294967295',
		     'frWanRxCLLMs' => '4294967295',
		     'frWanRxBytes' => '18446744073709551615',		## 64-bit
		     'frWanRxFrames' => '4294967295',
		     'frWanRxDrops' => '4294967295',
		     'frWanRxInvDLCI' => '4294967295',
		     'frWanRxInvRq' => '4294967295',
		     'frWanRxLmiPolls' => '4294967295',
		     'frWanRxSeqOnly' => '4294967295',
		     'frWanRxFullStat' => '4294967295',
		     'frWanRxTooBig' => '4294967295',
		     'frWanRxUnattDLCIs' => '4294967295',
		     'frWanTxBytes' => '18446744073709551615',		## 64-bit
		     'frWanTxFrames' => '4294967295',
		     'frWanTxDrops' => '4294967295',
		     'frWanTxFullStat' => '4294967295',
		     'frWanTxSeqOnly' => '4294967295',
		     'frWanTxInvRq' => '4294967295',
		     'frWanTxLmiPolls' => '4294967295',
		     'frWanTxNoBuff' => '4294967295',
		     'frWanTxStops' => '4294967295',
		     'frWanWanFlows' => '4294967295',
        },

 },

### ----------------------Block E1_Link ------------------------------------------##
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg E1_Link data',
        INPUT_FILE_DESCRIPTION => '^(E1_Link-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'hdlcRxErr\w+' => '4294967295',   ## 32-bit
            'hdlcRxOK' => '4294967295',   ## 32-bit
            'hdlcTx\w+' => '4294967295',   ## 32-bit
            'hdlcRxOctets' => '18446744073709551615',   ## 64-bit
        },
},

### ------------------------Block FRPvc ------------------------------------------#####
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg FRPvc data',
        INPUT_FILE_DESCRIPTION    => '^(FRPvc-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
		     'frPvcRxBECNs' => '4294967295',
		     'frPvcRxDe' => '4294967295',
		     'frPvcRxBytes' => '18446744073709551615',
		     'frPvcRxFECNs' => '4294967295',
		     'frPvcRxFrames' => '4294967295',
		     'frPvcRxStops' => '4294967295',
		     'frPvcTxBytes' => '18446744073709551615',
		     'frPvcTxFrames' => '4294967295',
		     'frPvcTxDe' => '4294967295',
		     'frPvcTxStops' => '4294967295',
        },

 },

### ------------------------Block IP --------------------------------------###
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg IP data',
        INPUT_FILE_DESCRIPTION    => '^(IP-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'True',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'ipReasm\w+' => '4294967295',			## 32-bit
		        'ipInHdrErrors' => '4294967295',
            		     'ipInAddrErrors' => '4294967295',
            'ipOutNoRoutes' => '4294967295',
            'ipFrag\w+' => '4294967295',			
            'ipForwDatagrams' => '18446744073709551615',	## 64-bit
            'ipInReceives' => '18446744073709551615',		## 64-bit
        },

 },

{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-IP-#-.*-#-.*-#-.*-#-.*-#-I.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            my $slot_id1 	= $data[1];
            my $slot_id2	= $data[2];
	    if ($slot_id2 =~ /^$/){
            	$d_ref->{"Slot_Id"} = $slot_id1;
	    } else {
            	$d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
	    }
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
                       delete $d_ref->{$name};
               }
            }

            return 0;
        },
        FILENAME_SUFFIX         => 'IP',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'IP',
},
 
## -------------------Block PXM -----------------------------------------###
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg PXM data',
        INPUT_FILE_DESCRIPTION    => '^(PXM-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'ifInOctets' => '18446744073709551615', ## 64-bit 
            'ifInPkts' => '18446744073709551615',   ## 64-bit
            'ifOutDiscards' => '4294967295',	     ## 32-bit
            'ifInDiscards' => '4294967295',	     ## 32-bit
            'ifOutOctets' => '18446744073709551615',## 64-bit
            'ifOutPkts' => '18446744073709551615',  ## 64-bit
        },

},
 
#### ----------------------Block ICMP -----------------------------####
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg ICMP data',
        INPUT_FILE_DESCRIPTION    => '^(ICMP-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'icmp\w+' => '4294967295',
        },

 },

{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-ICMP-#-.*-#-.*-#-.*-#-.*-#-I.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            my $slot_id1 	= $data[1];
            my $slot_id2	= $data[2];
	    if ($slot_id2 =~ /^$/){
            	$d_ref->{"Slot_Id"} = $slot_id1;
	    } else {
            	$d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
	    }
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
                       delete $d_ref->{$name};
               }
            }

            return 0;
        },
        FILENAME_SUFFIX         => 'ICMP',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'ICMP',
},

#### ----------------Block Ethernet -----------------------------------##
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg Ethernet data',
        INPUT_FILE_DESCRIPTION    => '^(Ethernet-#-).*-#-.*-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
		 OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'True',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'ethInError\w+' => '4294967295',	## 32-bit
            'ethInMF' => '4294967295',	## 32-bit
            'ethOutError\w+' => '4294967295',	## 32-bit
            'ethInPkts' => '18446744073709551615',	## 64-bit
            'ethOutPkts' => '18446744073709551615',	## 64-bit
        },

 },

{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id, Port_Id',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-Ethernet-#-.*-#-.*-#-.*-#-.*-#-I.pif',
        DATA_COUNTERS_OP => sub
        {
	     my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"} = $data[0];
            $d_ref->{"Slot_Id"} = $data[1];
            $d_ref->{"Port_Id"} = $data[2];
             for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
				delete $d_ref->{$name};
               }
            }
            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'Ethernet',
},


## * * * * OSPF_Filter * * * * ####
#### ------------- Block OSPF_Neighbor -----------------------------###
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for OSPF_Neighbor block',
	INPUT_FILE_DESCRIPTION => ['^osp-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'OSPF_Neighbor',
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'OSPF_Neighbor',
	REDUNDANT_DATA_COUNTERS => ['ospfIfEvents', 'ospfExternLsaCount', 'ospfOriginateNewLsas', 'ospfRxNewLsas', 'ospfAreaBdrRtrCount', 'ospfAreaLsaCount', 'ospfAsBdrRtrCount', 'ospfSpfRuns'],
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^OSPF_Neighbor-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'ospfNbrEvents',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg OSPF_Neighbor data',
        INPUT_FILE_DESCRIPTION    => '^(OSPF_Neighbor-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'True',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'ospf\w+' => '4294967295',
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id,NeighborIP',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-OSPF_Neighbor-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	  my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            $d_ref->{"Slot_Id"} = $data[1];
            $d_ref->{"NeighborIP"} = $data[2];
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
				delete $d_ref->{$name};
               }
            }

            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'OSPF_Neighbor',
},

### -----------------Block OSPF_Interface ----------------------------------###
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for OSPF_Interface block',
	INPUT_FILE_DESCRIPTION => ['^osp-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'OSPF_Interface',
	REDUNDANT_DATA_COUNTERS => ['ospfNbrEvents', 'ospfExternLsaCount', 'ospfOriginateNewLsas', 'ospfRxNewLsas', 'ospfAreaBdrRtrCount', 'ospfAreaLsaCount', 'ospfAsBdrRtrCount', 'ospfSpfRuns'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'OSPF_Interface',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^OSPF_Interface-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'ospfIfEvents',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg OSPF_Interface data',
        INPUT_FILE_DESCRIPTION    => '^(OSPF_Interface-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'True',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'ospf\w+' => '4294967295',
        },

 },

{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id,InterfaceIP',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-OSPF_Interface-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            $d_ref->{"Slot_Id"} = $data[1];
            $d_ref->{"InterfaceIP"} = $data[2];
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
				delete $d_ref->{$name};
               }
            }
            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'OSPF_Interface',
},

#### --------------------- Block OSPF_slot ----------------------------######
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for OSPF_slot block',
	INPUT_FILE_DESCRIPTION => ['^osp-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'OSPF_slot',
	REDUNDANT_DATA_COUNTERS => ['ospfNbrEvents', 'ospfIfEvents', 'ospfAreaBdrRtrCount', 'ospfAreaLsaCount', 'ospfAsBdrRtrCount', 'ospfSpfRuns'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'OSPF_slot',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^OSPF_slot-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'ospfOriginateNewLsas',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg OSPF_slot data',
        INPUT_FILE_DESCRIPTION    => '^(OSPF_slot-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
			'ospfOriginateNewLsas'	=>	'4294967295',
			'ospfRxNewLsas'		=>	'4294967295',
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id for OSPF_slot',
        INPUT_FILE_DESCRIPTION    => '^UNPEG-#-OSPF_slot-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            my $slot_id1 	= $data[1];
            my $slot_id2	= $data[2];
	    if ($slot_id2 =~ /^$/){
            	$d_ref->{"Slot_Id"} = $slot_id1;
	    } else {
            	$d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
	    }
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
                       delete $d_ref->{$name};
               }
            }

            return 0;
        },
        FILENAME_SUFFIX         => 'OSPF_slot',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'OSPF_slot',
},

##### -------------Block OSPF_Area --------------------------------###
{
        'RULE_TYPE' => 'JOIN',
        'RULE_DESC' => 'Join files for OSPF_Area block',
        'INPUT_FILE_DESCRIPTION'       => ['^osp-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        'PRODUCE_PIF' => "True",
        'OUTPUT_FORMAT' => 0,
        'OUTPUT_BLOCK_NAME' => 'OSPF_Area',
        'COUNTERS_TO_JOIN_ON' => ['Node_Id','moid'],
        'OUTPUT_FILENAME_START' => 'OSPF_Area',
        'TIME_JOINFILE_PRODUCED' => 0,
        'HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME' => ['Node_Id', 'mts_Date', 'mts_Time'],
        'REDUNDANT_HEADER_COUNTERS' => ['cbt_Date', 'ts', 'vn','ts_Time','cbt','cbt_Time','mts','Type','GMT_difference','ts_Date'],
        'REDUNDANT_DATA_COUNTERS' => ['Record_measurement_count','ospfNbrEvents','ospfIfEvents','ospfExternLsaCount','ospfRxNewLsas','ospfOriginateNewLsas','filterIpsecPacketsOnSlot','filterDeniedPacketsOnSlot','filterAllowedPacketsOnSlot','filterAllowedPackets','filterIpsecPackets','filterDeniedPackets'],
        'HOURS_TO_WAIT_FOR_PARTNER_FILES' => -1,
   },
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^OSPF_Area-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'ospfAreaBdrRtrCount',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg OSPF_Area data',
        INPUT_FILE_DESCRIPTION    => '^(OSPF_Area-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'ospfSpfRuns' => '4294967295',
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id,Area_Id',
        INPUT_FILE_DESCRIPTION => '^UNPEG-#-OSPF_Area-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            $d_ref->{"Slot_Id"} = $data[1];
            $d_ref->{"Area_Id"} = $data[2];
            for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
				delete $d_ref->{$name};
               }
            }
            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'OSPF_Area',
},

###### --------------------Block Filtering_SA ------------------------------####
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for Filtering_SA block ',
	INPUT_FILE_DESCRIPTION => ['^fil-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'Filtering_SA',
	REDUNDANT_DATA_COUNTERS => ['filterAllowedPacketsOnSlot', 'filterDeniedPacketsOnSlot', 'filterIpsecPacketsOnSlot'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'Filtering_SA',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^Filtering_SA-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'filterDeniedPackets',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg Filtering_SA data',
        INPUT_FILE_DESCRIPTION    => '^(Filtering_SA-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'filter\w+' => '4294967295',
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to ConnectionName,Direction',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-Filtering_SA-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	  my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"ConnectionName"} = $data[0];
            $d_ref->{"Direction"} = $data[1];
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
				delete $d_ref->{$name};
               }
            }
            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'Filtering_SA',
},

### -------------------- Block Filtering_Slot --------------------------##
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for Filtering_Slot block ',
	INPUT_FILE_DESCRIPTION => ['^fil-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'Filtering_Slot',
	REDUNDANT_DATA_COUNTERS => ['filterAllowedPackets', 'filterDeniedPackets', 'filterIpsecPackets'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'Filtering_Slot',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^Filtering_Slot-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'filterAllowedPacketsOnSlot',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg Filtering_Slot data',
        INPUT_FILE_DESCRIPTION    => '^(Filtering_Slot-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
		     'filterDeniedPacketsOnSlot' => '4294967295',		## 32-bit
		     'filterIpsecPacketsOnSlot' => '4294967295',
            'filterAllowedPacketsOnSlot' => '18446744073709551615', 	## 64-bit
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id for Filtering_Slot',
        INPUT_FILE_DESCRIPTION       => '^UNPEG-#-Filtering_Slot-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            my $slot_id1 	= $data[1];
            my $slot_id2	= $data[2];
	    if ($slot_id2 =~ /^$/){
            	$d_ref->{"Slot_Id"} = $slot_id1;
	    } else {
            	$d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
	    }
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
                       delete $d_ref->{$name};
               }
            }

            return 0;
        },
        FILENAME_SUFFIX         => 'Filtering_Slot',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'Filtering_Slot',
},

## * ** * SS7_PM * * * ####
### --------- Block Ssn --------------------------------------###
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for Ssn block',
	INPUT_FILE_DESCRIPTION => ['^ss7-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'Ssn',
	REDUNDANT_DATA_COUNTERS => [ 'ss7MessageReceivedPerLinkBb', 'ss7MessageSentPerLinkBb', 'ss7MessageReceivedPerLinkNb', 'ss7MessageSentPerLinkNb', 'ss7MSUDiscardError', 'ss7MessageOrigUDT', 'ss7MessageOrigXUDT', 'ss7MessageTermUDT', 'ss7MessageTermXUDT', 'ss7NoOfCurrRunConnTot', 'ss7NoOfIncSegMes', 'ss7NoOfRunDialTot', 'ss7NoOfRunOpTot', 'ss7ProtocolErrorComp', 'ss7ProtocolErrorTraA', 'ss7ProtocolErrorTraD', 'ss7SLFailure', 'ss7SLRestoration', 'ss7SPInaccess', 'ss7TCMessageReceive', 'ss7TCMessageSent'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'Ssn',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^Ssn-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'ss7NoOfRunDialPerSsn',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id,SSN',
        INPUT_FILE_DESCRIPTION => 'Ssn-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"} = $data[0];
            $d_ref->{"Slot_Id"} = $data[1];
            $d_ref->{"SSN"} = $data[2];
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
				delete $d_ref->{$name};
               }
            }
            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'Ssn',
},


##### -------------Block LinkNb --------------------------------###
{
        RULE_TYPE              => 'JOIN',
	      RULE_DESC              => 'Join files for LinkNb block',
        INPUT_FILE_DESCRIPTION          => ['^ss7-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
        OUTPUT_BLOCK_NAME               => 'LinkNb',
        REDUNDANT_DATA_COUNTERS         => [ 'ss7MessageOrigCR', 'ss7MessageOrigDT1', 'ss7MessageOrigRLSD', 'ss7MessageReceivedPerLinkBb', 'ss7MessageSentPerLinkBb', 'ss7MessageTermCR', 'ss7MessageTermDT1' ,'ss7MessageTermRLSD', 'ss7NoOfRunDialPerSsn', 'ss7NoOfRunOpPerSsn', 'ss7MSUDiscardError', 'ss7MessageOrigUDT', 'ss7MessageOrigXUDT', 'ss7MessageTermUDT', 'ss7MessageTermXUDT', 'ss7NoOfCurrRunConnTot', 'ss7NoOfIncSegMes', 'ss7NoOfRunDialTot', 'ss7NoOfRunOpTot', 'ss7ProtocolErrorComp', 'ss7ProtocolErrorTraA', 'ss7ProtocolErrorTraD', 'ss7SLFailure', 'ss7SLRestoration', 'ss7SPInaccess', 'ss7TCMessageReceive', 'ss7TCMessageSent'],
        PRODUCE_PIF            => 'True',
        PRODUCE_LIF            => 0,
        COUNTERS_TO_JOIN_ON             => [qw(Node_Id moid) ],
        HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
        HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
        OUTPUT_FILENAME_START           => 'LinkNb',
        REDUNDANT_HEADER_COUNTERS       => [],
},

{
        RULE_TYPE              => 'DATALINE_WHERE',
        RULE_DESC              => 'DATALINE example',
        INPUT_FILE_DESCRIPTION          => ['^(LinkNb-#-.*-#-).*-#-.*-#-.*-#-J.pif'],
        PRODUCE_PIF            => 'True',
        OUTPUT_FORMAT          => 0,
        COUNTER_NAMES          => [{
                            'COUNTER_NAME'  => 'ss7MessageReceivedPerLinkNb',
                            'KEEP_WHERE'  => [ '\d+' ],
                          },],
},
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg LinkNb data',
        INPUT_FILE_DESCRIPTION    => '^(LinkNb-#-.*-#-).*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'LIF_Writer',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
                      STARTDATE => 'mts_Date',
                      STARTTIME => 'mts_Time',
                      DURATION  => 'gp',
                      FORMAT    => 'seconds',
                    },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS              => {
                      'ss7\w+' => '4294967295',
                   },
},

{
        RULE_TYPE              => 'PERLIZE',
        RULE_DESC              => 'Unpacking moid to Mag_Id,Slot_Id,Trunk,Timeslot',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-LinkNb-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP       => sub {
                      my $d_ref = shift;
                      my @data = split('\.',$d_ref->{moid});
                     $d_ref->{"Mag_Id"} = $data[0];
                     $d_ref->{"Slot_Id"} = $data[1];
                     $d_ref->{"Trunk"} = $data[2];
                     $d_ref->{"Timeslot"} = $data[3];
                     for my $d_key (keys %$d_ref) {
                         my $name = $d_key;
                         if ($d_ref->{$name} =~ /NULL/) {
                             delete $d_ref->{$name};
                         }
                     }
                     return 0;
                },
        FILENAME_SUFFIX        => 'PL',
        OUTPUT_FORMAT          => "LIF_Writer",
        PRODUCE_PIF            => 0,
        OUTPUT_BLOCK_NAME      => 'LinkNb',
},

##### -------------Block SS7_Index --------------------------------###
{
        RULE_TYPE        => 'JOIN',
	      RULE_DESC        => 'Join files for SS7_Index block',
	      INPUT_FILE_DESCRIPTION    => ['^ss7-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	      OUTPUT_BLOCK_NAME         => 'SS7_Index',
	      REDUNDANT_DATA_COUNTERS   => [ 'ss7SPInaccess', 'ss7TCMessageSent', 'ss7ProtocolErrorComp', 'ss7MessageReceivedPerLinkNb', 'ss7AssocAvlForUP', 'ss7ProtocolErrorTraA', 'ss7NoOfRunOpTot', 'ss7AssocUnavlForUP', 'ss7ProtocolErrorTraD', 'ss7SLFailureNb', 'ss7SLRestorationNb', 'ss7MSUDiscardError', 'ss7NoOfRunDialTot', 'ss7MessageSentPerLinkNb', 'ss7TCMessageReceive', 'ss7NoOfRunDialPerSsn', 'Record_measurement_count', 'ss7NoOfRunOpPerSsn'], 
	      PRODUCE_PIF               => 'True',
	      PRODUCE_LIF               => 0,
	      COUNTERS_TO_JOIN_ON       => [qw(Node_Id moid) ],
	      HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	      HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	      OUTPUT_FILENAME_START     => 'SS7_Index',
	      REDUNDANT_HEADER_COUNTERS => [],
},

{
         RULE_TYPE                => 'DATALINE_WHERE',
         RULE_DESC                => 'DATALINE_WHERE to removed records without moid ',
	       INPUT_FILE_DESCRIPTION   => '^SS7_Index-#-.*-#-.*-#-.*-#-.*-#-J.pif',
         PRODUCE_PIF              => 'True',
         OUTPUT_FORMAT            => 0,
         COUNTER_NAMES            => [
                     {
                         COUNTER_NAME  => 'moid',
                         REMOVE_WHERE  => [ ],
                     },
                     {
                         COUNTER_NAME  => 'ss7MessageOrigUDT',
                         KEEP_WHERE  => [ '.+' ],
                     },
                     {
                         COUNTER_NAME  => 'ss7MessageOrigXUDT',
                         KEEP_WHERE  => [ '.+' ],
                     },                     
                     {
                         COUNTER_NAME  => 'ss7NoOfIncSegMes',
                         KEEP_WHERE  => [ '.+' ],
                     },                     
                     {
                         COUNTER_NAME  => 'ss7MessageTermXUDT',
                         KEEP_WHERE  => [ '.+' ],
                     },                     
                     {
                         COUNTER_NAME  => 'ss7MessageTermUDT',
                         KEEP_WHERE  => [ '.+' ],
                     },                     
                   ],
         OUTPUT_BLOCK_NAME        => 'SS7_Index',
},
 
{
         RULE_TYPE        => 'UNPEGGER',
         RULE_DESC        => 'Unpeg SS7_Index data',
         INPUT_FILE_DESCRIPTION    => '^(SS7_Index-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
         INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
         PEG_FILENAME_PREFIX       => 'SAVED',
         UNPEG_FILENAME_PREFIX     => 'UNPEG',
         UNPEG_FILE_TYPE           => 'HEADER',
         OUTPUT_FORMAT             => 0,
         PRODUCE_PIF               => 'TRUE',         
         KEEP_RAW_GRANULARITY      => 'TRUE',
         MAX_PEG_PIF_AGE           => 'DURATION*4+60',
         CALCULATE_ROLLOVER        => 'True',
         DEFAULT_NULL_VALUE        => '',
         DATETIME_COUNTERS         => {
                       STARTDATE => 'mts_Date',
                       STARTTIME => 'mts_Time',
                       DURATION  => 'gp',
                       FORMAT    => 'seconds',
                    },
         COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
         PEG_COUNTERS              => { 
                      'ss7Message\w+'    => '4294967295',
                      'ss7NoOfIncSegMes' => '4294967295',
                    },
},

{
        RULE_TYPE        => 'PERLIZE',
        RULE_DESC        => 'Unpacking moid to Mag_Id,Slot_Id for SS7_Index',
        INPUT_FILE_DESCRIPTION    => '^UNPEG-#-SS7_Index-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP          => sub {
	                    my $d_ref = shift;
	                    my @data = split('\.',$d_ref->{moid});
	                    $d_ref->{"Mag_Id"}  = $data[0];
	                    my $slot_id1 	= $data[1];
	                    my $slot_id2	= $data[2];
	                    
	                    if ($slot_id2 =~ /^$/){
	                        $d_ref->{"Slot_Id"} = $slot_id1;
	                    } else {
	                        $d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
	                    }
	                    
	                    for my $d_key (keys %$d_ref) {
	                        my $name = $d_key;
	                        if ($d_ref->{$name} =~ /NULL/) {
	                            delete $d_ref->{$name};
	                        }
	                    }
	                    
	                    return 0;
	                  },
        FILENAME_SUFFIX           => 'SS7_Index',
        OUTPUT_FORMAT             => 'LIF_Writer',
        PRODUCE_PIF               => 0,
        OUTPUT_BLOCK_NAME         => 'SS7_Index',
},

##### -------------Block SS7_nonindexed --------------------------------###

{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for SS7_nonindexed block',
	INPUT_FILE_DESCRIPTION => ['^ss7-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'SS7_nonindexed',
	REDUNDANT_DATA_COUNTERS => [ 'ss7MessageReceivedPerLinkNb', 'ss7SLFailureNb',  'ss7NoOfIncSegMes', 'ss7MessageOrigXUDT', 'ss7MessageTermXUDT', 'ss7SLRestorationNb', 'ss7MessageTermUDT', 'ss7MessageSentPerLinkNb', 'ss7NoOfRunDialPerSsn', 'ss7MessageOrigUDT', 'Record_measurement_count', 'ss7NoOfRunOpPerSsn'], 
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'SS7_nonindexed',
	REDUNDANT_HEADER_COUNTERS => [],
},

{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg SS7_nonindexed data',
        INPUT_FILE_DESCRIPTION    => '^(SS7_nonindexed-#-.*)-#-.*-#-.*-#-.*-#-J.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'ss7Message\w+'	=>	'4294967295',
            'ss7Assoc\w+'	=>	'4294967295',
            'ss7Protocol\w+'	=>	'4294967295',
            'ss7TC\w+'	=>	'4294967295',
            'ss7MSU\w+'	=>	'4294967295',
           'ss7SP\w+'	=>	'4294967295',
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id for SS7_nonindexed',
        INPUT_FILE_DESCRIPTION    => '^UNPEG-#-SS7_nonindexed-#-.*-#-.*-#-.*-#-.*-#-J.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            my $slot_id1 	= $data[1];
            my $slot_id2	= $data[2];
	    if ($slot_id2 =~ /^$/){
            	$d_ref->{"Slot_Id"} = $slot_id1;
	    } else {
            	$d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
	    }
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
                       delete $d_ref->{$name};
               }
            }

            return 0;
        },
        FILENAME_SUFFIX         => 'SS7_nonindex',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        OUTPUT_BLOCK_NAME                => 'SS7_nonindexed',
},

##### -------------Block Performance_Monitoring / PM --------------------------------###
{
	RULE_TYPE => 'PIF_2_OUTPUT',
	RULE_DESC => 'ouput Performance_Monitoring data',
	INPUT_FILE_DESCRIPTION => '^pmR-#-(.*-#-.*-#-.*)-#-.*-#-I.pif',
	OUTPUT_BLOCK_NAME => 'Performance_Monitoring',
	OUTPUT_FILENAME_START => 'Performance_Monitoring',
	REDUNDANT_HEADER_COUNTERS => [],
	REDUNDANT_DATA_COUNTERS => [],
	OUTPUT_FORMAT => 'LIF_Writer',
	PRODUCE_PIF => 0,
},

### * * * _SYS * * ###
##### -------------Block GPB --------------------------------###
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for GPB block',
	INPUT_FILE_DESCRIPTION => ['^SYS-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'GPB',
	REDUNDANT_DATA_COUNTERS => [ 'SYS_gsnCpuUsageIB'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'GPB',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^GPB-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => 'TRUE',
	 'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'SYS_gsnCpuUsageGPB',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id for GPB',
        INPUT_FILE_DESCRIPTION       => '^GPB-#-(.*-#-.*-#-.*)-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"}  = $data[0];
            my $slot_id1 	= $data[1];
            my $slot_id2	= $data[2];
	    if ($slot_id2 =~ /^$/){
            	$d_ref->{"Slot_Id"} = $slot_id1;
	    } else {
            	$d_ref->{"Slot_Id"} = $slot_id1."_".$slot_id2;
	    }
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
                       delete $d_ref->{$name};
               }
            }

            return 0;
        },
        FILENAME_SUFFIX         => 'GPB',
        OUTPUT_FORMAT           => "LIF_Writer",
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'GPB',
},
###------Block Ibxx------------------------------------------------------------
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'join files for IBxx block',
	INPUT_FILE_DESCRIPTION => ['^SYS-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'Ibxx',
	REDUNDANT_DATA_COUNTERS => [ 'SYS_gsnCpuUsageGPB', 'Record_measurement_count'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'Ibxx',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^Ibxx-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
	 'OUTPUT_FORMAT' => 'LIF_Writer',
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'SYS_gsnCpuUsageIB',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
###-------------------Block ATM_Layer-----------------------------------------------
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for ATM_Layer block',
	INPUT_FILE_DESCRIPTION => ['^atm-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'ATM_Layer',
	REDUNDANT_DATA_COUNTERS => [ 'atmal5CRCErrors', 'atmal5IfInDiscards', 'atmal5IfInErrors', 'atmal5IfInOctets', 'atmal5IfInPkts', 'atmtclCorrectableHECs', 'atmtclEgressCells', 'atmtclIngressCells', 'atmtclOCDEvents', 'atmtclUncorrectableHECs', 'atmal5IfOutDiscards', 'atmal5IfOutErrors', 'atmal5IfOutOctets', 'atmal5IfOutPkts', 'atmal5OverSizedSDUs', 'atmlCLPCells', 'atmlCPIErrors', 'atmlCellDrops', 'atmlCongestionErrors', 'atmlInvalidCells', 'atmlVpiVciLookupErrors'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'ATM_Layer',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^ATM_Layer-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'atmplPathAIS',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg ATM_Layer data',
        INPUT_FILE_DESCRIPTION    => '^(ATM_Layer-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS         => {
            'atmpl\w+' => '4294967295',
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id, Port_Id',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-ATM_Layer-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	    my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"} = $data[0];
            $d_ref->{"Slot_Id"} = $data[1];
            $d_ref->{"Port_Id"} = $data[2];
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
				delete $d_ref->{$name};
               }
            }
            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
        'OUTPUT_BLOCK_NAME'              => 'ATM_Layer',
},


#### --------------------ATM_Index -----------------------------##
{
	RULE_TYPE => 'JOIN',
	RULE_DESC => 'Join files for ATM_Index block',
	INPUT_FILE_DESCRIPTION => ['^atm-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
	OUTPUT_BLOCK_NAME => 'ATM_Index',
	REDUNDANT_DATA_COUNTERS => [ 'atmplOOF', 'atmplPathAIS', 'atmplPathOverheadBIPErrors', 'atmplPathRDI', 'atmplPathREI', 'atmplSectionOverheadBIPErrors', 'atmplLOF', 'atmplLOP', 'atmplLOS', 'atmplLineAIS', 'atmplLineOverheadBIPErrors', 'atmplLineRDI', 'atmplLineREI'],
	PRODUCE_PIF => 'True',
	PRODUCE_LIF => 0,
	COUNTERS_TO_JOIN_ON => [qw(Node_Id moid) ],
	HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
	HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
	OUTPUT_FILENAME_START => 'ATM_Index',
	REDUNDANT_HEADER_COUNTERS => [],
},
{
         'RULE_TYPE'           => 'DATALINE_WHERE',
         'RULE_DESC'           => 'DATALINE example',
         'INPUT_FILE_DESCRIPTION'       => ['^ATM_Index-#-(.*-#-.*-#-.*)-#-.*-#-J.pif'],
         'PRODUCE_PIF' => "True",
         'OUTPUT_FORMAT' => 0,
         'COUNTER_NAMES'  =>
             [
              {
         'COUNTER_NAME'  => 'atmtclIngressCells',
         'KEEP_WHERE'  => [ '\d+' ],
              },
              {
         'COUNTER_NAME'  => 'atmal5OverSizedSDUs',
         'KEEP_WHERE'  => [ '\d+' ],
              },
              {
         'COUNTER_NAME'  => 'atmlInvalidCells',
         'KEEP_WHERE'  => [ '\d+' ],
              },
             ],
  },
{
        RULE_TYPE        => 'UNPEGGER',
        RULE_DESC        => 'Unpeg ATM_Index data',
        INPUT_FILE_DESCRIPTION    => '^(ATM_Index-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 0,
        PRODUCE_PIF               => 'TRUE',
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
            STARTDATE => 'mts_Date',
            STARTTIME => 'mts_Time',
            DURATION  => 'gp',
            FORMAT    => 'seconds',
        },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id)],
        PEG_COUNTERS         => {
		     'atmal5CRCErrors' => '4294967295',			## 32-bit
		     'atmal5IfInDiscards' => '4294967295',		## 32-bit
		     'atmal5IfInErrors' => '4294967295',		## 32-bit
		     'atmal5IfInOctets' => '18446744073709551615',	## 64-bit
		     'atmal5IfInPkts' => '18446744073709551615',	## 64-bit
		     'atmal5IfOutDiscards' => '4294967295',		## 32-bit
		     'atmal5IfOutErrors' => '4294967295',		## 32-bit
		     'atmal5IfOutOctets' => '18446744073709551615',	## 64-bit
		     'atmal5IfOutPkts' => '18446744073709551615',	## 64-bit
		     'atmal5OverSizedSDUs' => '4294967295',		## 32-bit
		     'atmtclCorrectableHECs' => '4294967295',		## 32-bit
		     'atmtclEgressCells' => '18446744073709551615',	## 64-bit
		     'atmtclIngressCells' => '18446744073709551615',	## 64-bit
		     'atmtclOCDEvents' => '4294967295',			## 32-bit
		     'atmtclUncorrectableHECs' => '4294967295',		## 32-bit
		     'atmlCLPCells' => '4294967295',			## 32-bit
		     'atmlCPIErrors' => '4294967295',			## 32-bit
		     'atmlCellDrops' => '4294967295',			## 32-bit
		     'atmlCongestionErrors' => '4294967295',		## 32-bit
		     'atmlInvalidCells' => '4294967295',		## 32-bit
		     'atmlVpiVciLookupErrors' => '4294967295',		## 32-bit
        },

 },
{
        RULE_TYPE => 'PERLIZE',
        RULE_DESC => 'Unpacking moid to Mag_Id,Slot_Id, Port_Id',
        INPUT_FILE_DESCRIPTION => 'UNPEG-#-ATM_Index-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
        DATA_COUNTERS_OP => sub
        {
	      my $d_ref = shift;
            my @data = split('\.',$d_ref->{moid});
            $d_ref->{"Mag_Id"} = $data[0];
            $d_ref->{"Slot_Id"} = $data[1];
            $d_ref->{"Port_Id"} = $data[2];
              for my $d_key (keys %$d_ref) {
               my $name = $d_key;
               if ($d_ref->{$name} =~ /NULL/) {
                       delete $d_ref->{$name};
               }
            }
            return 0;
        },
        FILENAME_SUFFIX         => 'PL',
        OUTPUT_FORMAT           => 'LIF_Writer',
        PRODUCE_PIF             => 0,
        OUTPUT_BLOCK_NAME                => 'ATM_Index',
},

### --------------------------------LinkBd------------------------------------------------
##  Commented out since there are no sample data available for LinkBd blocks
# {
#         RULE_TYPE              => 'JOIN',
#         RULE_DESC              => 'Join files for LinkBd block',
#         INPUT_FILE_DESCRIPTION          => ['^ss7-#-(.*-#-.*-#-.*)-#-.*-#-I.pif'],
#         OUTPUT_BLOCK_NAME               => 'LinkBd',
#         REDUNDANT_DATA_COUNTERS         => [ 'ss7AssocUnavlForUP', 'ss7SLFailureNb', 'ss7SLRestorationNb', 'ss7AssocAvlForUP', 'ss7MessageOrigCR', 'ss7MessageOrigDT1', 'ss7MessageOrigRLSD', 'ss7MessageOrigUDT', 'ss7MessageOrigXUDT', 'ss7MessageTermCR', 'ss7MessageTermDT1', 'ss7MessageTermRLSD', 'ss7MessageTermUDT', 'ss7MessageTermXUDT', 'ss7MSUDiscardError', 'ss7NoOfCurrRunConnTot', 'ss7NoOfIncSegMes', 'ss7NoOfRunDialTot', 'ss7NoOfRunOpTot', 'ss7ProtocolErrorComp', 'ss7ProtocolErrorTraA', 'ss7ProtocolErrorTraD', 'ss7SLFailure', 'ss7SLRestoration', 'ss7SPInaccess', 'ss7TCMessageReceive', 'ss7TCMessageSent', 'ss7MessageReceivedPerLinkNb', 'ss7MessageSentPerLinkNb', 'ss7NoOfRunDialPerSsn', 'ss7NoOfRunOpPerSsn'],
#         PRODUCE_PIF            => 'True',
#         PRODUCE_LIF            => 0,
#         COUNTERS_TO_JOIN_ON             => [qw(Node_Id moid) ],
#         HEADER_COUNTERS_TO_USE_IN_OUTPUT_FILENAME => ['Node_Id', 'mts_Date', 'mts_Time'],
#         HOURS_TO_WAIT_FOR_PARTNER_FILES => -1,
#         OUTPUT_FILENAME_START           => 'LinkBd',
#         REDUNDANT_HEADER_COUNTERS       => [],
# },
# {
#          RULE_TYPE           => 'DATALINE_WHERE',
#          RULE_DESC           => 'DATALINE example',
#          INPUT_FILE_DESCRIPTION       => ['^(LinkBd-#-.*-#-).*-#-.*-#-.*-#-J.pif'],
#          PRODUCE_PIF => "True",
#          OUTPUT_FORMAT => 0,
#          COUNTER_NAMES  =>
#              [
#               {
#          'COUNTER_NAME'  => 'ss7MessageReceivedPerLinkBb',
#          'KEEP_WHERE'  => [ '\d+' ],
#               },
#               {
#          'COUNTER_NAME'  => 'ss7MessageSentPerLinkBb',
#          'KEEP_WHERE'  => [ '\d+' ],
#               },
#               {
#          'COUNTER_NAME'  => 'ss7SLFailureBb',
#          'KEEP_WHERE'  => [ '\d+' ],
#               },
#               {
#          'COUNTER_NAME'  => 'ss7SLRestorationBb',
#          'KEEP_WHERE'  => [ '\d+' ],
#               },
#              ],
# },
# {
#         RULE_TYPE        => 'UNPEGGER',
#         RULE_DESC        => 'Unpeg LinkBd data',
#         INPUT_FILE_DESCRIPTION    => '^(LinkBd-#-.*)-#-.*-#-.*-#-.*-#-J-#-DW.pif',
#         INPUT_FILE_DATETIME_KEY   => '^.*-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-J-#-DW.pif',
#         PEG_FILENAME_PREFIX       => 'SAVED',
#         UNPEG_FILENAME_PREFIX     => 'UNPEG',
#         UNPEG_FILE_TYPE           => 'HEADER',
#         OUTPUT_FORMAT             => 0,
#         PRODUCE_PIF               => 'TRUE',
#         KEEP_RAW_GRANULARITY      => 'TRUE',
#         MAX_PEG_PIF_AGE           => 'DURATION*4+60',
#         CALCULATE_ROLLOVER        => 'True',
#         DEFAULT_NULL_VALUE        => '',
#         DATETIME_COUNTERS         => {
#                       STARTDATE => 'mts_Date',
#                       STARTTIME => 'mts_Time',
#                       DURATION  => 'gp',
#                       FORMAT    => 'seconds',
#                    },
#         COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
#         PEG_COUNTERS              => { 'ss7\w+' => '4294967295',},
# 
# },
# {
#         RULE_TYPE        => 'PERLIZE',
#         RULE_DESC        => 'Unpacking moid to Mag_Id,Slot_Id',
#         INPUT_FILE_DESCRIPTION    => '^UNPEG-#-LinkBd-#-.*-#-.*-#-.*-#-.*-#-J-#-DW.pif',
#         DATA_COUNTERS_OP          => sub   {
#                       	         my $d_ref = shift;
#                        my @data = split('\.',$d_ref->{moid});
#                       $d_ref->{"Mag_Id"}  = $data[0];
#                       $d_ref->{"Slot_Id"} = $data[1];
#                       $d_ref->{"Port_Id"} = $data[2];
#                       for my $d_key (keys %$d_ref) {
#                           my $name = $d_key;
#                           if ($d_ref->{$name} =~ /NULL/) {
#                       				delete $d_ref->{$name};
#                           }
#                       }
#                       return 0;
#                    },
#         FILENAME_SUFFIX           => 'PL',
#         OUTPUT_FORMAT             => "LIF_Writer",
#         PRODUCE_PIF               => 0,
#         OUTPUT_BLOCK_NAME         => 'LinkBd',
# },

### -------------------------Block NSC_NSVC -----------------------------------##
{
        RULE_TYPE                 => 'UNPEGGER',
        RULE_DESC                 => 'Unpeg NSC_NSVC data',
        INPUT_FILE_DESCRIPTION    => '^(NSC_NSVC-#-)\d{2}\w{3}\d{4}-#-\d{2}:\d{2}:\d{2}-#-(.*)-#-.*-#-I.pif',
        INPUT_FILE_DATETIME_KEY   => '^NSC_NSVC-#-(\d{2}\w{3}\d{4}-#-\d{2}:\d{2}):\d{2}-#-.*-#-.*-#-I.pif',
        PEG_FILENAME_PREFIX       => 'SAVED',
        UNPEG_FILENAME_PREFIX     => 'UNPEG',
        UNPEG_FILE_TYPE           => 'HEADER',
        OUTPUT_FORMAT             => 'LIF_Writer',
        OUTPUT_BLOCK_NAME         => 'NSC_NSVC',
        PRODUCE_PIF               => 0,
        KEEP_RAW_GRANULARITY      => 'TRUE',
        MAX_PEG_PIF_AGE           => 'DURATION*4+60',
        CALCULATE_ROLLOVER        => 'True',
        DEFAULT_NULL_VALUE        => '',
        DATETIME_COUNTERS         => {
                                         STARTDATE => 'mts_Date',
                                         STARTTIME => 'mts_Time',
                                         DURATION  => 'gp',
                                         FORMAT    => 'seconds',
                                     },
        COUNTERS_TO_SORT_ON       => [qw(Node_Id moid)],
        PEG_COUNTERS              => {
                                         'ns\w+' => '4294967295',
                                     },
},

);
sub postparser_config {
        return \@rules;
}
1;
